<?php ?>
  <tr>
    <td style="max-width: 150px;"><img src="spacer.png" width="150" height="1" /></td>
    <td>&nbsp;</td>
  </tr>
</table>

<?php if(!$man) { ?>
  <p><a href="http://sourceforge.net/" target="_blank"><img
  src="http://sourceforge.net/sflogo.php?group_id=120202&amp;type=6"
  alt="SourceForge" border="0" /></a></p>
<?php } ?>

</body>
</html>
